==> node-semver_7.3.5+~7.3.9.orig.tar.gz: node-semver-7.3.5/test/fixtures/range-intersection.js <==
// r0, r1, expected intersection
module.exports = [
  ['1.3.0 || <1.0.0 >2.0.0', '1.3.0 || <1.0.0 >2.0.0', true],
  ['<1.0.0 >2.0.0', '>0.0.0', false],
  ['>0.0.0', '<1.0.0 >2.0.0', false],
  ['<1.0.0 >2.0.0', '>1.4.0 <1.6.0', false],
  ['<1.0.0 >2.0.0', '>1.4.0 <1.6.0 || 2.0.0', false],
  ['>1.0.0 <=2.0.0', '2.0.0', true],
  ['<1.0.0 >=2.0.0', '2.1.0', false],
  ['<1.0.0 >=2.0.0', '>1.4.0 <1.6.0 || 2.0.0', false],
  ['1.5.x', '<1.5.0 || >=1.6.0', false],
  ['<1.5.0 || >=1.6.0', '1.5.x', false],
  ['<1.6.16 || >=1.7.0 <1.7.11 || >=1.8.0 <1.8.2', '>=1.6.16 <1.7.0 || >=1.7.11 <1.8.0 || >=1.8.2', false],
  ['<=1.6.16 || >=1.7.0 <1.7.11 || >=1.8.0 <1.8.2', '>=1.6.16 <1.7.0 || >=1.7.11 <1.8.0 || >=1.8.2', true],
  ['>=1.0.0', '<=1.0.0', true],
  ['>1.0.0 <1.0.0', '<=0.0.0', false],
  ['*', '0.0.1', true],
  ['*', '>=1.0.0', true],
  ['*', '>1.0.0', true],
  ['*', '~1.0.0', true],
  ['*', '<1.6.0', true],
  ['*', '<=1.6.0', true],
  ['1.*', '0.0.1', false],
  ['1.*', '2.0.0', false],
  ['1.*', '1.0.0', true],
  ['1.*', '<2.0.0', true],
  ['1.*', '>1.0.0', true],
  ['1.*', '<=1.0.0', true],
  ['1.*', '^1.0.0', true],
  ['1.0.*', '0.0.1', false],
  ['1.0.*', '<0.0.1', false],
  ['1.0.*', '>0.0.1', true],
  ['*', '1.3.0 || <1.0.0 >2.0.0', true],
  ['1.3.0 || <1.0.0 >2.0.0', '*', true],
  ['1.*', '1.3.0 || <1.0.0 >2.0.0', true],
  ['x', '0.0.1', true],
  ['x', '>=1.0.0', true],
  ['x', '>1.0.0', true],
  ['x', '~1.0.0', true],
  ['x', '<1.6.0', true],
  ['x', '<=1.6.0', true],
  ['1.x', '0.0.1', false],
  ['1.x', '2.0.0', false],
  ['1.x', '1.0.0', true],
  ['1.x', '<2.0.0', true],
  ['1.x', '>1.0.0', true],
  ['1.x', '<=1.0.0', true],
  ['1.x', '^1.0.0', true],
  ['1.0.x', '0.0.1', false],
  ['1.0.x', '<0.0.1', false],
  ['1.0.x', '>0.0.1', true],
  ['x', '1.3.0 || <1.0.0 >2.0.0', true],
  ['1.3.0 || <1.0.0 >2.0.0', 'x', true],
  ['1.x', '1.3.0 || <1.0.0 >2.0.0', true],
  ['*', '*', true],
  ['x', '', true]
]

==> node-semver_7.6.1+~7.5.8.orig.tar.gz: node-semver-7.6.1/test/fixtures/range-intersection.js <==
// r0, r1, expected intersection
module.exports = [
  ['1.3.0 || <1.0.0 >2.0.0', '1.3.0 || <1.0.0 >2.0.0', true],
  ['<1.0.0 >2.0.0', '>0.0.0', false],
  ['>0.0.0', '<1.0.0 >2.0.0', false],
  ['<1.0.0 >2.0.0', '>1.4.0 <1.6.0', false],
  ['<1.0.0 >2.0.0', '>1.4.0 <1.6.0 || 2.0.0', false],
  ['>1.0.0 <=2.0.0', '2.0.0', true],
  ['<1.0.0 >=2.0.0', '2.1.0', false],
  ['<1.0.0 >=2.0.0', '>1.4.0 <1.6.0 || 2.0.0', false],
  ['1.5.x', '<1.5.0 || >=1.6.0', false],
  ['<1.5.0 || >=1.6.0', '1.5.x', false],
  ['<1.6.16 || >=1.7.0 <1.7.11 || >=1.8.0 <1.8.2',
    '>=1.6.16 <1.7.0 || >=1.7.11 <1.8.0 || >=1.8.2', false],
  ['<=1.6.16 || >=1.7.0 <1.7.11 || >=1.8.0 <1.8.2',
    '>=1.6.16 <1.7.0 || >=1.7.11 <1.8.0 || >=1.8.2', true],
  ['>=1.0.0', '<=1.0.0', true],
  ['>1.0.0 <1.0.0', '<=0.0.0', false],
  ['*', '0.0.1', true],
  ['*', '>=1.0.0', true],
  ['*', '>1.0.0', true],
  ['*', '~1.0.0', true],
  ['*', '<1.6.0', true],
  ['*', '<=1.6.0', true],
  ['1.*', '0.0.1', false],
  ['1.*', '2.0.0', false],
  ['1.*', '1.0.0', true],
  ['1.*', '<2.0.0', true],
  ['1.*', '>1.0.0', true],
  ['1.*', '<=1.0.0', true],
  ['1.*', '^1.0.0', true],
  ['1.0.*', '0.0.1', false],
  ['1.0.*', '<0.0.1', false],
  ['1.0.*', '>0.0.1', true],
  ['*', '1.3.0 || <1.0.0 >2.0.0', true],
  ['1.3.0 || <1.0.0 >2.0.0', '*', true],
  ['1.*', '1.3.0 || <1.0.0 >2.0.0', true],
  ['x', '0.0.1', true],
  ['x', '>=1.0.0', true],
  ['x', '>1.0.0', true],
  ['x', '~1.0.0', true],
  ['x', '<1.6.0', true],
  ['x', '<=1.6.0', true],
  ['1.x', '0.0.1', false],
  ['1.x', '2.0.0', false],
  ['1.x', '1.0.0', true],
  ['1.x', '<2.0.0', true],
  ['1.x', '>1.0.0', true],
  ['1.x', '<=1.0.0', true],
  ['1.x', '^1.0.0', true],
  ['1.0.x', '0.0.1', false],
  ['1.0.x', '<0.0.1', false],
  ['1.0.x', '>0.0.1', true],
  ['x', '1.3.0 || <1.0.0 >2.0.0', true],
  ['1.3.0 || <1.0.0 >2.0.0', 'x', true],
  ['1.x', '1.3.0 || <1.0.0 >2.0.0', true],
  ['*', '*', true],
  ['x', '', true],
]
